[Rt-commit] r5324 - in rtir/branches/1.9-EXPERIMENTAL: . inc/Module
inc/Module/Install/RTx
ruz at bestpractical.com
ruz at bestpractical.com
Thu Jun 1 19:36:02 EDT 2006
Author: ruz
Date: Thu Jun 1 19:36:00 2006
New Revision: 5324
Modified:
rtir/branches/1.9-EXPERIMENTAL/ (props changed)
rtir/branches/1.9-EXPERIMENTAL/inc/Module/AutoInstall.pm
rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install.pm
rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/AutoInstall.pm
rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Base.pm
rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Can.pm
rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Fetch.pm
rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Include.pm
rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Makefile.pm
rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Metadata.pm
rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/RTx.pm
rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/RTx/Factory.pm
rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Win32.pm
rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/WriteAll.pm
Log:
r1443 at cubic-pc: cubic | 2006-06-02 03:39:31 +0400
* update M::I
Modified: rtir/branches/1.9-EXPERIMENTAL/inc/Module/AutoInstall.pm
==============================================================================
--- rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install.pm (original)
+++ rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install.pm Thu Jun 1 19:36:00 2006
@@ -1,16 +1,44 @@
-#line 1 "/Users/kevinr/Source/BPS/RTIR-1.9/inc/Module/Install.pm - /sw/lib/perl5/site_perl/5.8.6//Module/Install.pm"
+#line 1
package Module::Install;
+# For any maintainers:
+# The load order for Module::Install is a bit magic.
+# It goes something like this...
+#
+# IF ( host has Module::Install installed, creating author mode ) {
+# 1. Makefile.PL calls "use inc::Module::Install"
+# 2. $INC{inc/Module/Install.pm} set to installed version of inc::Module::Install
+# 3. The installed version of inc::Module::Install loads
+# 4. inc::Module::Install calls "require Module::Install"
+# 5. The ./inc/ version of Module::Install loads
+# } ELSE {
+# 1. Makefile.PL calls "use inc::Module::Install"
+# 2. $INC{inc/Module/Install.pm} set to ./inc/ version of Module::Install
+# 3. The ./inc/ version of Module::Install loads
+# }
+
use 5.004;
use strict 'vars';
+
use vars qw{$VERSION};
BEGIN {
- # Don't forget to update Module::Install::Admin too!
- $VERSION = '0.52';
-}
-
-# inc::Module::Install must be loaded first
-unless ( $INC{join('/', inc => split(/::/, __PACKAGE__)).'.pm'} ) {
+ # All Module::Install core packages now require synchronised versions.
+ # This will be used to ensure we don't accidentally load old or
+ # different versions of modules.
+ # This is not enforced yet, but will be some time in the next few
+ # releases once we can make sure it won't clash with custom
+ # Module::Install extensions.
+ $VERSION = '0.62';
+}
+
+# Whether or not inc::Module::Install is actually loaded, the
+# $INC{inc/Module/Install.pm} is what will still get set as long as
+# the caller loaded module this in the documented manner.
+# If not set, the caller may NOT have loaded the bundled version, and thus
+# they may not have a MI version that works with the Makefile.PL. This would
+# result in false errors or unexpected behaviour. And we don't want that.
+my $file = join( '/', 'inc', split /::/, __PACKAGE__ ) . '.pm';
+unless ( $INC{$file} ) {
die <<"END_DIE";
Please invoke ${\__PACKAGE__} with:
@@ -24,26 +52,25 @@
}
use Cwd ();
-use FindBin;
use File::Find ();
use File::Path ();
+use FindBin;
*inc::Module::Install::VERSION = *VERSION;
- at inc::Module::Install::ISA = 'Module::Install';
+ at inc::Module::Install::ISA = __PACKAGE__;
sub autoload {
- my $self = shift;
- my $caller = $self->_caller;
- my $cwd = Cwd::cwd();
- my $sym = "$caller\::AUTOLOAD";
-
+ my $self = shift;
+ my $who = $self->_caller;
+ my $cwd = Cwd::cwd();
+ my $sym = "${who}::AUTOLOAD";
$sym->{$cwd} = sub {
my $pwd = Cwd::cwd();
if ( my $code = $sym->{$pwd} ) {
# delegate back to parent dirs
goto &$code unless $cwd eq $pwd;
}
- $$sym =~ /([^:]+)$/ or die "Cannot autoload $caller - $sym";
+ $$sym =~ /([^:]+)$/ or die "Cannot autoload $who - $sym";
unshift @_, ($self, $1);
goto &{$self->can('call')} unless uc($1) eq $1;
};
@@ -52,18 +79,18 @@
sub import {
my $class = shift;
my $self = $class->new(@_);
+ my $who = $self->_caller;
unless ( -f $self->{file} ) {
require "$self->{path}/$self->{dispatch}.pm";
File::Path::mkpath("$self->{prefix}/$self->{author}");
- $self->{admin} =
- "$self->{name}::$self->{dispatch}"->new(_top => $self);
+ $self->{admin} = "$self->{name}::$self->{dispatch}"->new( _top => $self );
$self->{admin}->init;
@_ = ($class, _self => $self);
goto &{"$self->{name}::import"};
}
- *{$self->_caller . "::AUTOLOAD"} = $self->autoload;
+ *{"${who}::AUTOLOAD"} = $self->autoload;
$self->preload;
# Unregister loader and worker packages so subdirs can use them again
@@ -74,11 +101,11 @@
sub preload {
my ($self) = @_;
- unless ( $self->{extentions} ) {
- $self->load_extensions(
- "$self->{prefix}/$self->{path}", $self
- );
- }
+ unless ( $self->{extensions} ) {
+ $self->load_extensions(
+ "$self->{prefix}/$self->{path}", $self
+ );
+ }
my @exts = @{$self->{extensions}};
unless ( @exts ) {
@@ -86,21 +113,21 @@
@exts = $admin->load_all_extensions;
}
- my %seen_method;
+ my %seen;
foreach my $obj ( @exts ) {
while (my ($method, $glob) = each %{ref($obj) . '::'}) {
- next unless defined *{$glob}{CODE};
+ next unless $obj->can($method);
next if $method =~ /^_/;
next if $method eq uc($method);
- $seen_method{$method}++;
+ $seen{$method}++;
}
}
- my $caller = $self->_caller;
- foreach my $name (sort keys %seen_method) {
- *{"${caller}::$name"} = sub {
- ${"${caller}::AUTOLOAD"} = "${caller}::$name";
- goto &{"${caller}::AUTOLOAD"};
+ my $who = $self->_caller;
+ foreach my $name ( sort keys %seen ) {
+ *{"${who}::$name"} = sub {
+ ${"${who}::AUTOLOAD"} = "${who}::$name";
+ goto &{"${who}::AUTOLOAD"};
};
}
}
@@ -118,30 +145,26 @@
$args{dispatch} ||= 'Admin';
$args{prefix} ||= 'inc';
- $args{author} ||= '.author';
+ $args{author} ||= ($^O eq 'VMS' ? '_author' : '.author');
$args{bundle} ||= 'inc/BUNDLES';
$args{base} ||= $base_path;
-
$class =~ s/^\Q$args{prefix}\E:://;
$args{name} ||= $class;
$args{version} ||= $class->VERSION;
-
- unless ($args{path}) {
+ unless ( $args{path} ) {
$args{path} = $args{name};
$args{path} =~ s!::!/!g;
}
$args{file} ||= "$args{base}/$args{prefix}/$args{path}.pm";
- bless(\%args, $class);
+ bless( \%args, $class );
}
sub call {
- my $self = shift;
- my $method = shift;
- my $obj = $self->load($method) or return;
-
- unshift @_, $obj;
- goto &{$obj->can($method)};
+ my ($self, $method) = @_;
+ my $obj = $self->load($method) or return;
+ splice(@_, 0, 2, $obj);
+ goto &{$obj->can($method)};
}
sub load {
@@ -167,13 +190,13 @@
}
sub load_extensions {
- my ($self, $path, $top_obj) = @_;
+ my ($self, $path, $top) = @_;
- unshift @INC, $self->{prefix}
- unless grep { $_ eq $self->{prefix} } @INC;
+ unless ( grep { lc $_ eq lc $self->{prefix} } @INC ) {
+ unshift @INC, $self->{prefix};
+ }
- local @INC = ($path, @INC);
- foreach my $rv ($self->find_extensions($path)) {
+ foreach my $rv ( $self->find_extensions($path) ) {
my ($file, $pkg) = @{$rv};
next if $self->{pathnames}{$pkg};
@@ -184,7 +207,7 @@
next;
}
$self->{pathnames}{$pkg} = delete $INC{$file};
- push @{$self->{extensions}}, &{$new}($pkg, _top => $top_obj );
+ push @{$self->{extensions}}, &{$new}($pkg, _top => $top );
}
$self->{extensions} ||= [];
@@ -197,10 +220,32 @@
File::Find::find( sub {
my $file = $File::Find::name;
return unless $file =~ m!^\Q$path\E/(.+)\.pm\Z!is;
- return if $1 eq $self->{dispatch};
+ my $subpath = $1;
+ return if lc($subpath) eq lc($self->{dispatch});
+
+ $file = "$self->{path}/$subpath.pm";
+ my $pkg = "$self->{name}::$subpath";
+ $pkg =~ s!/!::!g;
+
+ # If we have a mixed-case package name, assume case has been preserved
+ # correctly. Otherwise, root through the file to locate the case-preserved
+ # version of the package name.
+ if ( $subpath eq lc($subpath) || $subpath eq uc($subpath) ) {
+ open PKGFILE, "<$subpath.pm" or die "find_extensions: Can't open $subpath.pm: $!";
+ my $in_pod = 0;
+ while ( <PKGFILE> ) {
+ $in_pod = 1 if /^=\w/;
+ $in_pod = 0 if /^=cut/;
+ next if ($in_pod || /^=cut/); # skip pod text
+ next if /^\s*#/; # and comments
+ if ( m/^\s*package\s+($pkg)\s*;/i ) {
+ $pkg = $1;
+ last;
+ }
+ }
+ close PKGFILE;
+ }
- $file = "$self->{path}/$1.pm";
- my $pkg = "$self->{name}::$1"; $pkg =~ s!/!::!g;
push @found, [ $file, $pkg ];
}, $path ) if -d $path;
@@ -208,15 +253,13 @@
}
sub _caller {
- my $depth = 0;
- my $caller = caller($depth);
-
- while ($caller eq __PACKAGE__) {
+ my $depth = 0;
+ my $call = caller($depth);
+ while ( $call eq __PACKAGE__ ) {
$depth++;
- $caller = caller($depth);
+ $call = caller($depth);
}
-
- $caller;
+ return $call;
}
1;
Modified: rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/AutoInstall.pm
==============================================================================
--- rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/AutoInstall.pm (original)
+++ rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/AutoInstall.pm Thu Jun 1 19:36:00 2006
@@ -1,6 +1,15 @@
-#line 1 "inc/Module/Install/AutoInstall.pm - /sw/lib/perl5/site_perl/5.8.6//Module/Install/AutoInstall.pm"
+#line 1
package Module::Install::AutoInstall;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
+
+use strict;
+use Module::Install::Base;
+
+use vars qw{$VERSION $ISCORE @ISA};
+BEGIN {
+ $VERSION = '0.62';
+ $ISCORE = 1;
+ @ISA = qw{Module::Install::Base};
+}
sub AutoInstall { $_[0] }
Modified: rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Base.pm
==============================================================================
--- rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Base.pm (original)
+++ rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Base.pm Thu Jun 1 19:36:00 2006
@@ -1,47 +1,52 @@
-#line 1 "inc/Module/Install/Base.pm - /sw/lib/perl5/site_perl/5.8.6//Module/Install/Base.pm"
+#line 1
package Module::Install::Base;
+$VERSION = '0.62';
+
# Suspend handler for "redefined" warnings
-BEGIN { my $w = $SIG{__WARN__}; $SIG{__WARN__} = sub { $w } };
+BEGIN {
+ my $w = $SIG{__WARN__};
+ $SIG{__WARN__} = sub { $w };
+}
+
+### This is the ONLY module that shouldn't have strict on
+# use strict;
-#line 30
+#line 41
sub new {
my ($class, %args) = @_;
- foreach my $method (qw(call load)) {
+ foreach my $method ( qw(call load) ) {
*{"$class\::$method"} = sub {
- +shift->_top->$method(@_);
+ shift()->_top->$method(@_);
} unless defined &{"$class\::$method"};
}
- bless(\%args, $class);
+ bless( \%args, $class );
}
-#line 48
+#line 61
sub AUTOLOAD {
my $self = shift;
-
local $@;
my $autoload = eval { $self->_top->autoload } or return;
goto &$autoload;
}
-#line 62
+#line 76
sub _top { $_[0]->{_top} }
-#line 73
+#line 89
sub admin {
- my $self = shift;
- $self->_top->{admin} or Module::Install::Base::FakeAdmin->new;
+ $_[0]->_top->{admin} or Module::Install::Base::FakeAdmin->new;
}
sub is_admin {
- my $self = shift;
- $self->admin->VERSION;
+ $_[0]->admin->VERSION;
}
sub DESTROY {}
@@ -50,14 +55,16 @@
my $Fake;
sub new { $Fake ||= bless(\@_, $_[0]) }
+
sub AUTOLOAD {}
-sub DESTROY {}
-1;
+sub DESTROY {}
# Restore warning handler
-BEGIN { $SIG{__WARN__} = $SIG{__WARN__}->() };
+BEGIN {
+ $SIG{__WARN__} = $SIG{__WARN__}->();
+}
-__END__
+1;
-#line 120
+#line 138
Modified: rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Can.pm
==============================================================================
--- rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Can.pm (original)
+++ rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Can.pm Thu Jun 1 19:36:00 2006
@@ -1,68 +1,82 @@
-#line 1 "inc/Module/Install/Can.pm - /sw/lib/perl5/site_perl/5.8.6//Module/Install/Can.pm"
+#line 1
package Module::Install::Can;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
-$VERSION = '0.01';
use strict;
+use Module::Install::Base;
use Config ();
+### This adds a 5.005 Perl version dependency.
+### This is a bug and will be fixed.
use File::Spec ();
use ExtUtils::MakeMaker ();
+use vars qw{$VERSION $ISCORE @ISA};
+BEGIN {
+ $VERSION = '0.62';
+ $ISCORE = 1;
+ @ISA = qw{Module::Install::Base};
+}
+
# check if we can load some module
+### Upgrade this to not have to load the module if possible
sub can_use {
- my ($self, $mod, $ver) = @_;
- $mod =~ s{::|\\}{/}g;
- $mod .= ".pm" unless $mod =~ /\.pm$/i;
-
- my $pkg = $mod;
- $pkg =~ s{/}{::}g;
- $pkg =~ s{\.pm$}{}i;
+ my ($self, $mod, $ver) = @_;
+ $mod =~ s{::|\\}{/}g;
+ $mod .= '.pm' unless $mod =~ /\.pm$/i;
+
+ my $pkg = $mod;
+ $pkg =~ s{/}{::}g;
+ $pkg =~ s{\.pm$}{}i;
- local $@;
- eval { require $mod; $pkg->VERSION($ver || 0); 1 };
+ local $@;
+ eval { require $mod; $pkg->VERSION($ver || 0); 1 };
}
# check if we can run some command
sub can_run {
- my ($self, $cmd) = @_;
+ my ($self, $cmd) = @_;
- my $_cmd = $cmd;
- return $_cmd if (-x $_cmd or $_cmd = MM->maybe_command($_cmd));
+ my $_cmd = $cmd;
+ return $_cmd if (-x $_cmd or $_cmd = MM->maybe_command($_cmd));
- for my $dir ((split /$Config::Config{path_sep}/, $ENV{PATH}), '.') {
- my $abs = File::Spec->catfile($dir, $_[1]);
- return $abs if (-x $abs or $abs = MM->maybe_command($abs));
- }
+ for my $dir ((split /$Config::Config{path_sep}/, $ENV{PATH}), '.') {
+ my $abs = File::Spec->catfile($dir, $_[1]);
+ return $abs if (-x $abs or $abs = MM->maybe_command($abs));
+ }
- return;
+ return;
}
+# can we locate a (the) C compiler
sub can_cc {
- my $self = shift;
- my @chunks = split(/ /, $Config::Config{cc}) or return;
+ my $self = shift;
+ my @chunks = split(/ /, $Config::Config{cc}) or return;
- # $Config{cc} may contain args; try to find out the program part
- while (@chunks) {
- return $self->can_run("@chunks") || (pop(@chunks), next);
- }
+ # $Config{cc} may contain args; try to find out the program part
+ while (@chunks) {
+ return $self->can_run("@chunks") || (pop(@chunks), next);
+ }
- return;
+ return;
}
# Fix Cygwin bug on maybe_command();
-if ($^O eq 'cygwin') {
- require ExtUtils::MM_Cygwin;
- if (!defined(&ExtUtils::MM_Cygwin::maybe_command)) {
- *ExtUtils::MM_Cygwin::maybe_command = sub {
- my ($self, $file) = @_;
- if ($file =~ m{^/cygdrive/}i) {
- ExtUtils::MM_Win32->maybe_command($file);
- }
- else {
- $self->SUPER::maybe_command($file);
- }
- }
- }
+if ( $^O eq 'cygwin' ) {
+ require ExtUtils::MM_Cygwin;
+ require ExtUtils::MM_Win32;
+ if ( ! defined(&ExtUtils::MM_Cygwin::maybe_command) ) {
+ *ExtUtils::MM_Cygwin::maybe_command = sub {
+ my ($self, $file) = @_;
+ if ($file =~ m{^/cygdrive/}i and ExtUtils::MM_Win32->can('maybe_command')) {
+ ExtUtils::MM_Win32->maybe_command($file);
+ } else {
+ ExtUtils::MM_Unix->maybe_command($file);
+ }
+ }
+ }
}
1;
+
+__END__
+
+#line 157
Modified: rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Fetch.pm
==============================================================================
--- rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Fetch.pm (original)
+++ rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Fetch.pm Thu Jun 1 19:36:00 2006
@@ -1,15 +1,22 @@
-#line 1 "inc/Module/Install/Fetch.pm - /sw/lib/perl5/site_perl/5.8.6//Module/Install/Fetch.pm"
+#line 1
package Module::Install::Fetch;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
-$VERSION = '0.01';
+use strict;
+use Module::Install::Base;
+
+use vars qw{$VERSION $ISCORE @ISA};
+BEGIN {
+ $VERSION = '0.62';
+ $ISCORE = 1;
+ @ISA = qw{Module::Install::Base};
+}
sub get_file {
my ($self, %args) = @_;
my ($scheme, $host, $path, $file) =
$args{url} =~ m|^(\w+)://([^/]+)(.+)/(.+)| or return;
- if ($scheme eq 'http' and !eval { require LWP::Simple; 1 }) {
+ if ( $scheme eq 'http' and ! eval { require LWP::Simple; 1 } ) {
$args{url} = $args{ftp_url}
or (warn("LWP support unavailable!\n"), return);
($scheme, $host, $path, $file) =
@@ -53,14 +60,14 @@
chdir $dir; return;
}
- my @dialog = split(/\n/, << ".");
+ my @dialog = split(/\n/, <<"END_FTP");
open $host
user anonymous anonymous\@example.com
cd $path
binary
get $file $file
quit
-.
+END_FTP
foreach (@dialog) { $fh->print("$_\n") }
$fh->close;
} }
Modified: rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Include.pm
==============================================================================
--- rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Include.pm (original)
+++ rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Include.pm Thu Jun 1 19:36:00 2006
@@ -1,10 +1,34 @@
-#line 1 "inc/Module/Install/Include.pm - /sw/lib/perl5/site_perl/5.8.6//Module/Install/Include.pm"
+#line 1
package Module::Install::Include;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
-sub include { +shift->admin->include(@_) };
-sub include_deps { +shift->admin->include_deps(@_) };
-sub auto_include { +shift->admin->auto_include(@_) };
-sub auto_include_deps { +shift->admin->auto_include_deps(@_) };
+use strict;
+use Module::Install::Base;
+
+use vars qw{$VERSION $ISCORE @ISA};
+BEGIN {
+ $VERSION = '0.62';
+ $ISCORE = 1;
+ @ISA = qw{Module::Install::Base};
+}
+
+sub include {
+ shift()->admin->include(@_);
+}
+
+sub include_deps {
+ shift()->admin->include_deps(@_);
+}
+
+sub auto_include {
+ shift()->admin->auto_include(@_);
+}
+
+sub auto_include_deps {
+ shift()->admin->auto_include_deps(@_);
+}
+
+sub auto_include_dependent_dists {
+ shift()->admin->auto_include_dependent_dists(@_);
+}
1;
Modified: rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Makefile.pm
==============================================================================
--- rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Makefile.pm (original)
+++ rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Makefile.pm Thu Jun 1 19:36:00 2006
@@ -1,19 +1,37 @@
-#line 1 "inc/Module/Install/Makefile.pm - /sw/lib/perl5/site_perl/5.8.6//Module/Install/Makefile.pm"
+#line 1
package Module::Install::Makefile;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
-
-$VERSION = '0.01';
use strict 'vars';
-use vars '$VERSION';
-
+use Module::Install::Base;
use ExtUtils::MakeMaker ();
+use vars qw{$VERSION $ISCORE @ISA};
+BEGIN {
+ $VERSION = '0.62';
+ $ISCORE = 1;
+ @ISA = qw{Module::Install::Base};
+}
+
sub Makefile { $_[0] }
-sub prompt {
+my %seen = ();
+
+sub prompt {
shift;
- goto &ExtUtils::MakeMaker::prompt;
+
+ # Infinite loop protection
+ my @c = caller();
+ if ( ++$seen{"$c[1]|$c[2]|$_[0]"} > 3 ) {
+ die "Caught an potential prompt infinite loop ($c[1]|$c[2]|$_[0])";
+ }
+
+ # In automated testing, always use defaults
+ if ( $ENV{AUTOMATED_TESTING} and ! $ENV{PERL_MM_USE_DEFAULT} ) {
+ local $ENV{PERL_MM_USE_DEFAULT} = 1;
+ goto &ExtUtils::MakeMaker::prompt;
+ } else {
+ goto &ExtUtils::MakeMaker::prompt;
+ }
}
sub makemaker_args {
@@ -23,8 +41,19 @@
$args;
}
-sub build_subdirs {
+# For mm args that take multiple space-seperated args,
+# append an argument to the current list.
+sub makemaker_append {
my $self = shift;
+ my $name = shift;
+ my $args = $self->makemaker_args;
+ $args->{name} = defined $args->{$name}
+ ? join( ' ', $args->{name}, @_ )
+ : join( ' ', @_ );
+}
+
+sub build_subdirs {
+ my $self = shift;
my $subdirs = $self->makemaker_args->{DIR} ||= [];
for my $subdir (@_) {
push @$subdirs, $subdir;
@@ -32,17 +61,26 @@
}
sub clean_files {
- my $self = shift;
+ my $self = shift;
my $clean = $self->makemaker_args->{clean} ||= {};
%$clean = (
%$clean,
- FILES => join(" ", grep length, $clean->{FILES}, @_),
+ FILES => join(' ', grep length, $clean->{FILES}, @_),
+ );
+}
+
+sub realclean_files {
+ my $self = shift;
+ my $realclean = $self->makemaker_args->{realclean} ||= {};
+ %$realclean = (
+ %$realclean,
+ FILES => join(' ', grep length, $realclean->{FILES}, @_),
);
}
sub libs {
my $self = shift;
- my $libs = ref $_[0] ? shift : [shift];
+ my $libs = ref $_[0] ? shift : [ shift ];
$self->makemaker_args( LIBS => $libs );
}
@@ -56,25 +94,26 @@
die "&Makefile->write() takes no arguments\n" if @_;
my $args = $self->makemaker_args;
-
$args->{DISTNAME} = $self->name;
- $args->{NAME} = $self->module_name || $self->name || $self->determine_NAME($args);
- $args->{VERSION} = $self->version || $self->determine_VERSION($args);
- $args->{NAME} =~ s/-/::/g;
-
- $args->{test} = {TESTS => $self->tests} if $self->tests;
-
+ $args->{NAME} = $self->module_name || $self->name || $self->determine_NAME($args);
+ $args->{VERSION} = $self->version || $self->determine_VERSION($args);
+ $args->{NAME} =~ s/-/::/g;
+ if ( $self->tests ) {
+ $args->{test} = { TESTS => $self->tests };
+ }
if ($] >= 5.005) {
$args->{ABSTRACT} = $self->abstract;
- $args->{AUTHOR} = $self->author;
+ $args->{AUTHOR} = $self->author;
}
if ( eval($ExtUtils::MakeMaker::VERSION) >= 6.10 ) {
$args->{NO_META} = 1;
}
- if ( eval($ExtUtils::MakeMaker::VERSION) > 6.17 ) {
- $args->{SIGN} = 1 if $self->sign;
+ if ( eval($ExtUtils::MakeMaker::VERSION) > 6.17 and $self->sign ) {
+ $args->{SIGN} = 1;
+ }
+ unless ( $self->is_admin ) {
+ delete $args->{SIGN};
}
- delete $args->{SIGN} unless $self->is_admin;
# merge both kinds of requires into prereq_pm
my $prereq = ($args->{PREREQ_PM} ||= {});
@@ -91,49 +130,62 @@
}
}
- if (my $perl_version = $self->perl_version) {
+ if ( my $perl_version = $self->perl_version ) {
eval "use $perl_version; 1"
- or die "ERROR: perl: Version $] is installed, ".
- "but we need version >= $perl_version";
+ or die "ERROR: perl: Version $] is installed, "
+ . "but we need version >= $perl_version";
}
- my %args = map {($_ => $args->{$_})} grep {defined($args->{$_})} keys %$args;
-
+ my %args = map { ( $_ => $args->{$_} ) } grep {defined($args->{$_})} keys %$args;
if ($self->admin->preop) {
$args{dist} = $self->admin->preop;
}
- ExtUtils::MakeMaker::WriteMakefile(%args);
-
- $self->fix_up_makefile();
+ my $mm = ExtUtils::MakeMaker::WriteMakefile(%args);
+ $self->fix_up_makefile($mm->{FIRST_MAKEFILE} || 'Makefile');
}
sub fix_up_makefile {
- my $self = shift;
- my $top_class = ref($self->_top) || '';
- my $top_version = $self->_top->VERSION || '';
+ my $self = shift;
+ my $makefile_name = shift;
+ my $top_class = ref($self->_top) || '';
+ my $top_version = $self->_top->VERSION || '';
my $preamble = $self->preamble
- ? "# Preamble by $top_class $top_version\n" . $self->preamble
- : '';
- my $postamble = "# Postamble by $top_class $top_version\n" .
- ($self->postamble || '');
+ ? "# Preamble by $top_class $top_version\n"
+ . $self->preamble
+ : '';
+ my $postamble = "# Postamble by $top_class $top_version\n"
+ . ($self->postamble || '');
local *MAKEFILE;
- open MAKEFILE, '< Makefile' or die $!;
+ open MAKEFILE, "< $makefile_name" or die "fix_up_makefile: Couldn't open $makefile_name: $!";
my $makefile = do { local $/; <MAKEFILE> };
- close MAKEFILE;
+ close MAKEFILE or die $!;
$makefile =~ s/\b(test_harness\(\$\(TEST_VERBOSE\), )/$1'inc', /;
$makefile =~ s/( -I\$\(INST_ARCHLIB\))/ -Iinc$1/g;
$makefile =~ s/( "-I\$\(INST_LIB\)")/ "-Iinc"$1/g;
+ $makefile =~ s/^(FULLPERL = .*)/$1 "-Iinc"/m;
+ $makefile =~ s/^(PERL = .*)/$1 "-Iinc"/m;
- $makefile =~ s/^(FULLPERL = .*)/$1 -Iinc/m;
- $makefile =~ s/^(PERL = .*)/$1 -Iinc/m;
+ # Module::Install will never be used to build the Core Perl
+ # Sometimes PERL_LIB and PERL_ARCHLIB get written anyway, which breaks
+ # PREFIX/PERL5LIB, and thus, install_share. Blank them if they exist
+ $makefile =~ s/^PERL_LIB = .+/PERL_LIB =/m;
+ #$makefile =~ s/^PERL_ARCHLIB = .+/PERL_ARCHLIB =/m;
+
+ # Perl 5.005 mentions PERL_LIB explicitly, so we have to remove that as well.
+ $makefile =~ s/("?)-I\$\(PERL_LIB\)\1//g;
+
+ # XXX - This is currently unused; not sure if it breaks other MM-users
+ # $makefile =~ s/^pm_to_blib\s+:\s+/pm_to_blib :: /mg;
+
+ open MAKEFILE, "> $makefile_name" or die "fix_up_makefile: Couldn't open $makefile_name: $!";
+ print MAKEFILE "$preamble$makefile$postamble" or die $!;
+ close MAKEFILE or die $!;
- open MAKEFILE, '> Makefile' or die $!;
- print MAKEFILE "$preamble$makefile$postamble";
- close MAKEFILE;
+ 1;
}
sub preamble {
@@ -144,7 +196,6 @@
sub postamble {
my ($self, $text) = @_;
-
$self->{postamble} ||= $self->admin->postamble;
$self->{postamble} .= $text if defined $text;
$self->{postamble}
@@ -154,4 +205,4 @@
__END__
-#line 286
+#line 334
Modified: rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Metadata.pm
==============================================================================
--- rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Metadata.pm (original)
+++ rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Metadata.pm Thu Jun 1 19:36:00 2006
@@ -1,13 +1,14 @@
-#line 1 "inc/Module/Install/Metadata.pm - /sw/lib/perl5/site_perl/5.8.6//Module/Install/Metadata.pm"
+#line 1
package Module::Install::Metadata;
use strict 'vars';
use Module::Install::Base;
-use vars qw($VERSION @ISA);
+use vars qw{$VERSION $ISCORE @ISA};
BEGIN {
- $VERSION = '0.06';
- @ISA = 'Module::Install::Base';
+ $VERSION = '0.62';
+ $ISCORE = 1;
+ @ISA = qw{Module::Install::Base};
}
my @scalar_keys = qw{
@@ -62,6 +63,16 @@
return $self;
}
+sub dynamic_config {
+ my $self = shift;
+ unless ( @_ ) {
+ warn "You MUST provide an explicit true/false value to dynamic_config, skipping\n";
+ return $self;
+ }
+ $self->{'values'}{'dynamic_config'} = $_[0] ? 1 : 0;
+ return $self;
+}
+
sub all_from {
my ( $self, $file ) = @_;
@@ -130,8 +141,7 @@
# The user used ->feature like ->features by passing in the second
# argument as a reference. Accomodate for that.
$mods = $_[0];
- }
- else {
+ } else {
$mods = \@_;
}
@@ -154,7 +164,9 @@
while ( my ( $name, $mods ) = splice( @_, 0, 2 ) ) {
$self->feature( $name, @$mods );
}
- return @{ $self->{values}{features} };
+ return $self->{values}->{features}
+ ? @{ $self->{values}->{features} }
+ : ();
}
sub no_index {
@@ -226,11 +238,13 @@
^
use \s*
v?
- ([\d\.]+)
+ ([\d_\.]+)
\s* ;
/ixms
)
{
+ my $v = $1;
+ $v =~ s{_}{}g;
$self->perl_version($1);
}
else {
Modified: rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/RTx.pm
==============================================================================
--- rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/RTx.pm (original)
+++ rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/RTx.pm Thu Jun 1 19:36:00 2006
@@ -1,4 +1,4 @@
-#line 1 "inc/Module/Install/RTx.pm - /sw/lib/perl5/site_perl/5.8.6//Module/Install/RTx.pm"
+#line 1
package Module::Install::RTx;
use Module::Install::Base; @ISA = qw(Module::Install::Base);
@@ -40,7 +40,7 @@
until ( eval { require RT; $RT::LocalPath } ) {
warn "Cannot find the location of RT.pm that defines \$RT::LocalPath in: @INC\n";
$_ = $self->prompt("Path to your RT.pm:") or exit;
- push @INC, $_, "$_/rt3/lib", "$_/lib/rt3";
+ push @INC, $_, "$_/rt3/lib", "$_/lib/rt3", "$_/lib";
}
}
Modified: rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/RTx/Factory.pm
==============================================================================
--- rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/RTx/Factory.pm (original)
+++ rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/RTx/Factory.pm Thu Jun 1 19:36:00 2006
@@ -1,4 +1,4 @@
-#line 1 "inc/Module/Install/RTx/Factory.pm - /sw/lib/perl5/site_perl/5.8.6//Module/Install/RTx/Factory.pm"
+#line 1
package Module::Install::RTx::Factory;
use Module::Install::Base; @ISA = qw(Module::Install::Base);
@@ -11,6 +11,8 @@
unshift @INC, substr(delete($INC{'RT.pm'}), 0, -5) if $INC{'RT.pm'};
require RT;
+ unshift @INC, "$RT::LocalPath/lib" if $RT::LocalPath;
+
$RT::SbinPath ||= $RT::LocalPath;
$RT::SbinPath =~ s/local$/sbin/;
@@ -22,8 +24,10 @@
RT::LoadConfig();
my $lib_path = File::Basename::dirname($INC{'RT.pm'});
- my @args = (
- "-Ilib", "-I$lib_path",
+ my @args = ("-Ilib");
+ push @args, "-I$RT::LocalPath/lib" if $RT::LocalPath;
+ push @args, (
+ "-I$lib_path",
"$RT::SbinPath/rt-setup-database",
"--action" => $action,
"--datadir" => "etc",
Modified: rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Win32.pm
==============================================================================
--- rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Win32.pm (original)
+++ rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/Win32.pm Thu Jun 1 19:36:00 2006
@@ -1,40 +1,45 @@
-#line 1 "inc/Module/Install/Win32.pm - /sw/lib/perl5/site_perl/5.8.6//Module/Install/Win32.pm"
+#line 1
package Module::Install::Win32;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
-
-$VERSION = '0.02';
use strict;
+use Module::Install::Base;
+
+use vars qw{$VERSION $ISCORE @ISA};
+BEGIN {
+ $VERSION = '0.62';
+ $ISCORE = 1;
+ @ISA = qw{Module::Install::Base};
+}
# determine if the user needs nmake, and download it if needed
sub check_nmake {
- my $self = shift;
- $self->load('can_run');
- $self->load('get_file');
-
- require Config;
- return unless (
- $Config::Config{make} and
- $Config::Config{make} =~ /^nmake\b/i and
- $^O eq 'MSWin32' and
- !$self->can_run('nmake')
- );
-
- print "The required 'nmake' executable not found, fetching it...\n";
-
- require File::Basename;
- my $rv = $self->get_file(
- url => 'http://download.microsoft.com/download/vc15/Patch/1.52/W95/EN-US/Nmake15.exe',
- ftp_url => 'ftp://ftp.microsoft.com/Softlib/MSLFILES/Nmake15.exe',
- local_dir => File::Basename::dirname($^X),
- size => 51928,
- run => 'Nmake15.exe /o > nul',
- check_for => 'Nmake.exe',
- remove => 1,
- );
+ my $self = shift;
+ $self->load('can_run');
+ $self->load('get_file');
+
+ require Config;
+ return unless (
+ $^O eq 'MSWin32' and
+ $Config::Config{make} and
+ $Config::Config{make} =~ /^nmake\b/i and
+ ! $self->can_run('nmake')
+ );
+
+ print "The required 'nmake' executable not found, fetching it...\n";
+
+ require File::Basename;
+ my $rv = $self->get_file(
+ url => 'http://download.microsoft.com/download/vc15/Patch/1.52/W95/EN-US/Nmake15.exe',
+ ftp_url => 'ftp://ftp.microsoft.com/Softlib/MSLFILES/Nmake15.exe',
+ local_dir => File::Basename::dirname($^X),
+ size => 51928,
+ run => 'Nmake15.exe /o > nul',
+ check_for => 'Nmake.exe',
+ remove => 1,
+ );
- if (!$rv) {
- die << '.';
+ if (!$rv) {
+ die <<'END_MESSAGE';
-------------------------------------------------------------------------------
@@ -53,11 +58,8 @@
You may then resume the installation process described in README.
-------------------------------------------------------------------------------
-.
- }
+END_MESSAGE
+ }
}
1;
-
-__END__
-
Modified: rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/WriteAll.pm
==============================================================================
--- rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/WriteAll.pm (original)
+++ rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install/WriteAll.pm Thu Jun 1 19:36:00 2006
@@ -1,6 +1,15 @@
-#line 1 "inc/Module/Install/WriteAll.pm - /sw/lib/perl5/site_perl/5.8.6//Module/Install/WriteAll.pm"
+#line 1
package Module::Install::WriteAll;
-use Module::Install::Base; @ISA = qw(Module::Install::Base);
+
+use strict;
+use Module::Install::Base;
+
+use vars qw{$VERSION $ISCORE @ISA};
+BEGIN {
+ $VERSION = '0.62';
+ $ISCORE = 1;
+ @ISA = qw{Module::Install::Base};
+}
sub WriteAll {
my $self = shift;
@@ -12,22 +21,20 @@
@_
);
- $self->sign(1) if $args{sign};
- $self->Meta->write if $args{meta};
+ $self->sign(1) if $args{sign};
+ $self->Meta->write if $args{meta};
$self->admin->WriteAll(%args) if $self->is_admin;
- if ($0 =~ /Build.PL$/i) {
+ if ( $0 =~ /Build.PL$/i ) {
$self->Build->write;
- }
- else {
+ } else {
$self->check_nmake if $args{check_nmake};
- $self->makemaker_args( PL_FILES => {} )
- unless $self->makemaker_args->{'PL_FILES'};
-
+ unless ( $self->makemaker_args->{'PL_FILES'} ) {
+ $self->makemaker_args( PL_FILES => {} );
+ }
if ($args{inline}) {
$self->Inline->write;
- }
- else {
+ } else {
$self->Makefile->write;
}
}
More information about the Rt-commit
mailing list
--- rtir/branches/1.9-EXPERIMENTAL/inc/Module/AutoInstall.pm (original)
+++ rtir/branches/1.9-EXPERIMENTAL/inc/Module/AutoInstall.pm Thu Jun 1 19:36:00 2006
@@ -1,12 +1,14 @@
-#line 1 "inc/Module/AutoInstall.pm - /sw/lib/perl5/site_perl/5.8.6//Module/AutoInstall.pm"
+#line 1
package Module::AutoInstall;
-$Module::AutoInstall::VERSION = '1.01';
use strict;
use Cwd ();
use ExtUtils::MakeMaker ();
-#line 216
+use vars qw{$VERSION};
+BEGIN {
+ $VERSION = '1.02';
+}
# special map on pre-defined feature sets
my %FeatureMap = (
@@ -19,7 +21,8 @@
my ( $Config, $CheckOnly, $SkipInstall, $AcceptDefault, $TestOnly );
my ( $PostambleActions, $PostambleUsed );
-_accept_default( !-t STDIN ); # see if it's a non-interactive session
+# See if it's a testing or non-interactive session
+_accept_default( $ENV{AUTOMATED_TESTING} or ! -t STDIN );
_init();
sub _accept_default {
@@ -88,11 +91,11 @@
# the workhorse
sub import {
my $class = shift;
- my @args = @_ or return;
+ my @args = @_ or return;
my $core_all;
print "*** $class version " . $class->VERSION . "\n";
- print "*** Checking for dependencies...\n";
+ print "*** Checking for Perl dependencies...\n";
my $cwd = Cwd::cwd();
@@ -234,22 +237,25 @@
# CPAN.pm is non-reentrant, so check if we're under it and have no CPANPLUS
sub _check_lock {
return unless @Missing;
- return if _has_cpanplus();
+ _load_cpan();
- require CPAN;
- CPAN::Config->load;
+ # Find the CPAN lock-file
my $lock = MM->catfile( $CPAN::Config->{cpan_home}, ".lock" );
+ return unless -f $lock;
- if ( -f $lock
- and open( LOCK, $lock )
- and ( $^O eq 'MSWin32' ? _under_cpan() : <LOCK> == getppid() )
- and ( $CPAN::Config->{prerequisites_policy} || '' ) ne 'ignore' )
- {
- print << '.';
+ # Check the lock
+ local *LOCK;
+ return unless open(LOCK, $lock);
+
+ if (
+ ( $^O eq 'MSWin32' ? _under_cpan() : <LOCK> == getppid() )
+ and ( $CPAN::Config->{prerequisites_policy} || '' ) ne 'ignore'
+ ) {
+ print <<'END_MESSAGE';
*** Since we're running under CPAN, I'll just let it take care
of the dependency's installation later.
-.
+END_MESSAGE
$UnderCPAN = 1;
}
@@ -294,10 +300,9 @@
@modules = @newmod;
}
- if ( _has_cpanplus() ) {
+ if ( ! $UnderCPAN and _has_cpanplus() ) {
_install_cpanplus( \@modules, \@config );
- }
- else {
+ } else {
_install_cpan( \@modules, \@config );
}
@@ -320,7 +325,7 @@
sub _install_cpanplus {
my @modules = @{ +shift };
- my @config = @{ +shift };
+ my @config = _cpanplus_config( @{ +shift } );
my $installed = 0;
require CPANPLUS::Backend;
@@ -333,21 +338,22 @@
# if we're root, set UNINST=1 to avoid trouble unless user asked for it.
my $makeflags = $conf->get_conf('makeflags') || '';
if ( UNIVERSAL::isa( $makeflags, 'HASH' ) ) {
-
# 0.03+ uses a hashref here
$makeflags->{UNINST} = 1 unless exists $makeflags->{UNINST};
- }
- else {
+ } else {
# 0.02 and below uses a scalar
$makeflags = join( ' ', split( ' ', $makeflags ), 'UNINST=1' )
if ( $makeflags !~ /\bUNINST\b/ and eval qq{ $> eq '0' } );
+
}
$conf->set_conf( makeflags => $makeflags );
$conf->set_conf( prereqs => 1 );
+
+
while ( my ( $key, $val ) = splice( @config, 0, 2 ) ) {
- eval { $conf->set_conf( $key, $val ) };
+ $conf->set_conf( $key, $val );
}
my $modtree = $cp->module_tree;
@@ -372,15 +378,13 @@
if ( $rv and ( $rv->{ $obj->{module} } or $rv->{ok} ) ) {
print "*** $pkg successfully installed.\n";
$success = 1;
- }
- else {
+ } else {
print "*** $pkg installation cancelled.\n";
$success = 0;
}
$installed += $success;
- }
- else {
+ } else {
print << ".";
*** Could not find a version $ver or above for $pkg; skipping.
.
@@ -392,14 +396,34 @@
return $installed;
}
+sub _cpanplus_config {
+ my @config = ();
+ while ( @_ ) {
+ my ($key, $value) = (shift(), shift());
+ if ( $key eq 'prerequisites_policy' ) {
+ if ( $value eq 'follow' ) {
+ $value = CPANPLUS::Internals::Constants::PREREQ_INSTALL();
+ } elsif ( $value eq 'ask' ) {
+ $value = CPANPLUS::Internals::Constants::PREREQ_ASK();
+ } elsif ( $value eq 'ignore' ) {
+ $value = CPANPLUS::Internals::Constants::PREREQ_IGNORE();
+ } else {
+ die "*** Cannot convert option $key = '$value' to CPANPLUS version.\n";
+ }
+ } else {
+ die "*** Cannot convert option $key to CPANPLUS version.\n";
+ }
+ }
+ return @config;
+}
+
sub _install_cpan {
my @modules = @{ +shift };
my @config = @{ +shift };
my $installed = 0;
my %args;
- require CPAN;
- CPAN::Config->load;
+ _load_cpan();
require Config;
if (CPAN->VERSION < 1.80) {
@@ -593,6 +617,19 @@
return eval { require $file; $mod->VERSION } || ( $@ ? undef: 0 );
}
+# Load CPAN.pm and it's configuration
+sub _load_cpan {
+ return if $CPAN::VERSION;
+ require CPAN;
+ if ( $CPAN::HandleConfig::VERSION ) {
+ # Newer versions of CPAN have a HandleConfig module
+ CPAN::HandleConfig->load;
+ } else {
+ # Older versions had the load method in Config directly
+ CPAN::Config->load;
+ }
+}
+
# compare two versions, either use Sort::Versions or plain comparison
sub _version_check {
my ( $cur, $min ) = @_;
@@ -656,7 +693,7 @@
$PostambleActions = (
$missing
? "\$(PERL) $0 --config=$config --installdeps=$missing"
- : "\@\$(NOOP)"
+ : "\$(NOECHO) \$(NOOP)"
);
return %args;
@@ -697,7 +734,7 @@
return << ".";
config :: installdeps
-\t\@\$(NOOP)
+\t\$(NOECHO) \$(NOOP)
checkdeps ::
\t\$(PERL) $0 --checkdeps
@@ -713,4 +750,4 @@
__END__
-#line 943
+#line 988
Modified: rtir/branches/1.9-EXPERIMENTAL/inc/Module/Install.pm
==============================================================================